dlsia.test\_data package
=============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dlsia.test_data.two_d

Module contents
---------------

.. automodule:: dlsia.test_data
   :members:
   :undoc-members:
   :show-inheritance:
